% CMNG_main.m
% Continuum Model for Neurite Outgrowth
% Code Version 1.0 (BPG & DRM 5-2-05)
% Principles of Computational Modelling in Neuroscience
% Sterratt, Graham, Gillies, Willshaw
% Cambridge University Press, June 2011
% Fig. 10.8: Large, moderate & small growth regimes
% B. Graham, Computing Science & Maths, University of Stirling
% Contact: b.graham@cs.stir.ac.uk
% Last update: 1-7-2011

% Parameters

% simulation
simp.dt = 0.01;                  % time step
simp.tmax = 5000;                % simulation time
simp.datat = 1000;               % data collection time step
simp.N = 100;                    % number of spatial points
simp.kmax = 10000;               % maximum corrector steps
simp.mc = 0.0001;                % tolerance on C;
simp.ml = 0.0001;                % tolerance on l;

% user-defined
modp.c0 = 10;                    % concentration scale
modp.l0 = 0.01;                  % initial (min) length;
modp.D = 30000;                  % diffusion constant
modp.a = 100;                    % active transport rate
modp.g = 0.002;                  % decay rate
modp.rg = 10;                    % growth rate constant
modp.sg = 100;                   % growth rate set point (threshold)
k1 = 0.5;                        % alpha_twid_h value
k2 = 0.00001;                    % assembly to concentration scale
modp.e0 = modp.g*modp.sg/(k1*modp.c0*modp.rg*modp.a);  % soma flux-source rate
theta = 0;                       % fractional autoregulation
modp.er = theta*modp.e0;         % soma tubulin autoregulation
modp.rdt = 0;                    % autoregulation time delay
modp.el = k2*modp.rg;            % growth cone flux-sink rate
modp.zl = k2*modp.sg;            % growth cone flux-source rate

% plot parameters
% Note: for compatability with Inkscape output, which uses 90ppi,
% font sizes are given in pixels - stored as pts in SVG (BPG 21-9-09)
tsize=9;
lsize=9;
nsize=9;
lwidth=0.8;
fname='Arial';
lcol=[0.66275 0.82353 1.0];

doruns = 1;     % flag to run simulations

% Large growth
if (doruns == 1)
% Run 1: linear ICs
k1 = 0.5;
modp.e0 = modp.g*modp.sg/(k1*modp.c0*modp.rg*modp.a); 
% calculated parameters
[calcp] = CMNG_calcparams(simp, modp);
% run model for jmax time steps, linear ICs
[Cl1, C0l1, CNl1, ll1] = CMNG_run(simp, modp, calcp, -1, modp);
[t, Cl1, C0l1, CNl1, ll1] = CMNG_dimen(simp, modp, Cl1, C0l1, CNl1, ll1);  % dimensionalise
Cal1 = [C0l1 Cl1 CNl1];
end

% Plot results 
subplot(1,3,1);
hold on;
plot(t,ll1,'k-', 'LineWidth', lwidth);
title('(a) Large','FontSize',tsize,'FontName',fname);
ylabel('{\it l} (\mum)','FontSize',lsize,'FontName',fname);
xlabel('{\it t} (hours)','FontSize',lsize,'FontName',fname);
%axis([0 1 0 tmax]);
set(gca,'Box','off','TickDir','out','LineWidth',lwidth,'FontSize',nsize,'FontName',fname,'FontUnits','pixels');


% Moderate growth
if (doruns == 1)
% Run 1: linear ICs
k1 = 1;
modp.e0 = modp.g*modp.sg/(k1*modp.c0*modp.rg*modp.a); 
% calculated parameters
[calcp] = CMNG_calcparams(simp, modp);
% run model for jmax time steps, linear ICs
[Cm1, C0m1, CNm1, lm1] = CMNG_run(simp, modp, calcp, -1, modp);
[t, Cm1, C0m1, CNm1, lm1] = CMNG_dimen(simp, modp, Cm1, C0m1, CNm1, lm1);  % dimensionalise
Cam1 = [C0m1 Cm1 CNm1];
end

% Plot results 
subplot(1,3,2);
hold on;
plot(t,lm1,'k-', 'LineWidth', lwidth);
title('(b) Moderate','FontSize',tsize,'FontName',fname);
xlabel('{\it t} (hours)','FontSize',lsize,'FontName',fname);
%axis([0 1 0 tmax]);
set(gca,'Box','off','TickDir','out','LineWidth',lwidth,'FontSize',nsize,'FontName',fname,'FontUnits','pixels');


% Small growth
if (doruns == 1)
% Run 1: linear ICs
simp.tmax = 200;
simp.datat = 100;
k1 = 10;
modp.e0 = modp.g*modp.sg/(k1*modp.c0*modp.rg*modp.a); 
% calculated parameters
[calcp] = CMNG_calcparams(simp, modp);
% run model for jmax time steps, linear ICs
[Cs1, C0s1, CNs1, ls1] = CMNG_run(simp, modp, calcp, -1, modp);
[t, Cs1, C0s1, CNs1, ls1] = CMNG_dimen(simp, modp, Cs1, C0s1, CNs1, ls1);  % dimensionalise
Cas1 = [C0s1 Cs1 CNs1];
end

% Plot results
subplot(1,3,3);
hold on;
plot(t,ls1,'k-', 'LineWidth', lwidth);
title('(c) Small','FontSize',tsize,'FontName',fname);
xlabel('{\it t} (hours)','FontSize',lsize,'FontName',fname);
%axis([0 1 0 tmax]);
set(gca,'Box','off','TickDir','out','LineWidth',lwidth,'FontSize',nsize,'FontName',fname,'FontUnits','pixels');

